#!/usr/bin/env python
# coding: utf-8

from datetime import datetime
import pandas as pd
from pathlib import Path


def get_table():
    # Paths
    project_path = Path(__file__).parents[1].resolve()
    data_path = project_path / 'ufesp' / 'data'
    data_path.mkdir(exist_ok=True)

    # ddd
    df = pd.read_csv(
        data_path / 'ufesp.csv',
        parse_dates=['data_inicio', 'data_fim', 'ano_mes'],
        decimal=','
    )
    df.loc[:, 'ano_mes'] = pd.to_datetime(df['data_inicio']).dt.to_period('M')
    return df


def get_ufesp_from_date(date):
    # Get Dataframe
    df = get_table()

    # Json
    mask = (df['data_inicio'] <= date) & (df['data_fim'] >= date)
    return df.loc[mask].to_dict('records')[0]


def get_ufesp_from_year(year):
    # Get Dataframe
    df = get_table()

    # Create Year Columns
    df['data_inicio_year'] = pd.DatetimeIndex(df['data_inicio']).year
    df['data_fim_year'] = pd.DatetimeIndex(df['data_fim']).year

    # Json
    mask = (df['data_inicio_year'] <= year) & (df['data_fim_year'] >= year)
    return df.loc[mask].to_dict('records')[0]


if __name__ == '__main__':
    # Com dia (string)
    dados = get_ufesp_from_date(date='2020-11-15')
    print(dados['valor'])

    # Com dia (datetime)
    a = '2021-11-15'
    b = datetime.strptime(a, '%Y-%m-%d')
    dados = get_ufesp_from_date(date=b)
    print(dados['valor'])

    # Com Ano
    dados = get_ufesp_from_year(2022)
    print(dados['valor'])



#!/usr/bin/env python
# coding: utf-8


from pathlib import Path

# Paths
project_path = Path(__file__).parents[1].resolve()
data_path = project_path / 'ufesp' / 'data'
data_path.mkdir(exist_ok=True)

if __name__ == '__main__':
    print(f'A pasta do projeto é: {project_path}')
    print(f'A pasta dos dados é: {data_path}')



from setuptools import setup, find_packages

with open('README.md', 'r') as f:
    long_description = f.read()

requirements = []
for line in open('requirements.txt'):
    li = line.strip()
    if not li.startswith('#'):
        requirements.append(line.rstrip())

VERSION = (0, 0, 12)  # (1, 0, 7, 'dev0')
__version__ = '.'.join(map(str, VERSION))

setup(
    # Nome (não precisa ser o nome do repositório, nem de qualquer pasta...)
    name='ufesp',
    version=__version__,
    author='Michel Metran',
    author_email='michelmetran@gmail.com',
    description='Série Temporal da Unidade Fiscal do Estado de São Paulo e métodos para recuperar informações da UFESP',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/gaemapiracicaba/sp_sefaz_ufesp',
    keywords='python, ufesp, finance',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Natural Language :: Portuguese',
        'Intended Audience :: Developers',
    ],

    # Qual python? e packages?
    python_requires='>=3',
    install_requires=requirements,

    # Entry
    # Our packages live under src but src is not a package itself
    #package_dir={'': 'ufesp'},

    # Quando são diversos módulos...
    #packages=find_packages('ufesp', exclude=['test']),
    packages=['ufesp'],

    # Apenas um módulo...
    # py_modules=['decreto_estadual_8468'],  # Quando se trata apenas de um módulo

    # Dados
    include_package_data=True,
    package_data={'': ['data/ufesp.csv']},
)
